<?php 
/**
 * Copyright oceanwebguru.com 2022
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    Radadiya Ajay <aradadiya163@rest.com>
 * @copyright oceanwebguru.com 2022
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 * @version   1.0
 * oceanwebguru.com
 * Languages: EN
 * PS version: 1.6
**/

if (!defined('_PS_VERSION_')) {
    exit;
}
class ocproductinquiry extends Module
{
    public function __construct()
    {
        $this->module_key = '1539c7f8802bf7bede6057fa3f590f4f';
        $this->name = 'ocproductinquiry';
        $this->tab = 'front_office_features';
        $this->version = '1.0.2';
        $this->author = 'Ajay Radadiya';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = [
            'min' => '1.6',
            'max' => _PS_VERSION_,
        ];
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('OC Product Inquiry');
        $this->description = $this->l('Easy Inquiry with contact form for Products.');
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
        if (!Configuration::get('MYMODULE_NAME')) {
            $this->warning = $this->l('No name provided');
        }
    }

    public function install()
    {
        $sql = 'CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'oc_product_inquiri` (
            `pro_inq_id` INT UNSIGNED NOT NULL AUTO_INCREMENT,
            `hidden_product_name` VARCHAR(255) NOT NULL,
            `product_inq_url` VARCHAR(255) NOT NULL,
            `cus_name` VARCHAR(255) NOT NULL,
            `cus_mail` VARCHAR(255) NOT NULL,
            `cus_number` VARCHAR(255) NOT NULL,
            `cus_inquiery` TEXT NOT NULL,
            `pro_inq_curnt_time` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
            PRIMARY KEY (`pro_inq_id`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8;';

        if (!Db::getInstance()->execute($sql)) {
            return false;
        }

        if (!parent::install() or
            !$this->registerHook('displayReassurance') or
            !$this->registerHook('displayProductAdditionalInfo') or
            !$this->registerHook('displayBackOfficeHeader') or
            !$this->registerHook('displayProductTabContent') or
            !$this->createTab() or
            !$this->registerHook('header')) {
            return false;
        }

        return true;
    }

    public function uninstall()
    {
        if (!parent::uninstall()) {
            return false;
        }
        $sql = 'DROP TABLE IF EXISTS `oc_product_inquiri`';

        if (!Db::getInstance()->execute($sql)) {
            return false;
        }

        return true;
    }

    public function hookDisplayProductAdditionalInfo($params)
    {
        $params = $this->getParams();
        $this->context->smarty->assign([
                'custom_tab_title' => $this->l('Custom Tab'),
            ]);
        $this->context->smarty->assign($params);

        return $this->display(__FILE__, '/views/templates/front/product_inq_outofstock.tpl');
    }

    public function createTab()
    {
        $tab = new Tab();
        $tab->name = [];
        foreach (Language::getLanguages() as $lang) {
            $tab->name[$lang['id_lang']] = $this->l('Inquiry');
        }
        $tab->class_name = 'Adminproductinquirys';
        $tab->module = $this->name;
        $tab->icon = 'analytics';
        $tab->id_parent = (int)Tab::getIdFromClassName('SELL');
        $tab->add();

        return true;
    }

    public function hookDisplayProductTabContent($params)
    {
        $params = $this->getParams();
        $this->context->smarty->assign($params);

        return $this->display(__FILE__, 'views/templates/hook/product_inq_front_tab.tpl');
    }

    public function hookDisplayHeader()
    {
        $params = $this->getParams();
        $this->context->smarty->assign($params);
        $myData = [
            'ajaxcontrollerlink' => $this->context->link->getModuleLink('ocproductinquiry', 'productinquirys', ['ajax' => true,'action' => 'MyControllerAction']),
            'CUS_NAME_ERROR_MSG' => Configuration::get('CUS_NAME_ERROR_MSG'),
            'INQFORM_EMAIL_REQUIRE_TEXT' => Configuration::get('INQFORM_EMAIL_REQUIRE_TEXT'),
            'INQFORM_CUSNUMBER_REQ_TEXT' => Configuration::get('INQFORM_CUSNUMBER_REQ_TEXT'),
            'INQFORM_INQMSG_ERRORTEXT' => Configuration::get('INQFORM_INQMSG_ERRORTEXT'),
            'INQFORM_CUSNAME_REQUIRE' => Configuration::get('INQFORM_CUSNAME_REQUIRE'),
            'INQFORM_CUSEMAIL_REQ' => Configuration::get('INQFORM_CUSEMAIL_REQ'),
            'INQFORM_CUSMAIL_REQ_ENABLE' => Configuration::get('INQFORM_CUSMAIL_REQ_ENABLE'),
            'INQFORM_MSG_REQ_ENABLE' => Configuration::get('INQFORM_MSG_REQ_ENABLE'),
            'OCPRODUCT_INQ_TAB_CONTENT' => $this->fetch('module:ocproductinquiry/views/templates/hook/product_inq_front_tabcontent.tpl'),
            'PROINQ_FORM_LOCATIONS' => Configuration::get('PRODUCTINQUIRY_FORM_LOCATION'),
            'PROINQ_TAB_TITLE' => Configuration::get('INQFORM_PRO_TAB_TITLE')
        ];
        $jsonData = json_encode($myData);
        $this->context->controller->registerJavascript(
            $this->name,
            $this->_path . 'views/js/product_inq_front.js',
            [
                'position' => 'bottom',
                'priority' => 150,
                'server' => 'remote',
                'attributes' => 'async',
            ],
        );

        Media::addJsDef(['myData' => $myData]);
        $this->context->controller->addCSS($this->_path . '/views/css/product_inquiery_front.css', 'all');
    }

    public function hookDisplayBackOfficeHeader()
    {
        if (Tools::getValue('configure') == 'ocproductinquiry' || Tools::getValue('controller') == 'Adminproductinquirysedit') {
            $this->context->controller->addCSS($this->_path . '/views/css/coloris.min.css', 'all');
            $this->context->controller->addCSS($this->_path . '/views/css/product_inq_back.css', 'all');
            $this->context->controller->addJS($this->_path . '/views/js/coloris.min.js', 'all');
            $this->context->controller->addJS($this->_path . '/views/js/product_inq_admin.js', 'all');
        }
    }

    public function hookdisplayReassurance($params)
    {
        $params = $this->getParams();
        $this->context->smarty->assign($params);

        return $this->display(__FILE__, '/views/templates/front/prouct_inquiry_front.tpl');
    }

    public function getParams()
    {
        $params = [
            'PROINQ_ON_OFF',
            'PROINQ_PRICE_EMPTY',
            'PROINQ_HIDE_ATC_BTN',
            'PROINQ_STOCK_EMPTY',
            'PROINQ_HIDE_ATC_STOCK_EMPTY',
            'PRODUCTINQUIRY_FORM_LOCATION',
            'INQFORM_NAME_LABEL',
            'CUS_NAME_ERROR_MSG',
            'INQFORM_CUSNAME_REQUIRE',
            'INQFORM_EMAIL_LABEL',
            'INQFORM_EMAIL_REQUIRE_TEXT',
            'INQFORM_CUSEMAIL_REQ',
            'INQFORM_CUSNUMBER_LABEL',
            'INQFORM_CUSNUMBER_REQ_TEXT',
            'INQFORM_CUSMAIL_REQ_ENABLE',
            'INQFORM_INQMSG_LABEL',
            'INQFORM_INQMSG_ERRORTEXT',
            'INQFORM_MSG_REQ_ENABLE',
            'INQFORM_POPUP_TITLE',
            'INQFORM_PRO_TAB_TITLE',
            'INQFORM_FORM_BTN_TITLE',
            'INQFORM_SUBBTN_TEXT',
            'INQFORM_SUCCESS_MSG',
            'PROINQ_POPUP_BG_COLOR',
            'PROINQ_POPUP_HEADING_CLR',
            'PROINQ_POPUP_LABEL_CLR',
            'PROINQ_BUTTON_CLR',
            'PROINQ_BUTTON_SUB_TEXT_CLR',
            'PROINQ_BUTTON_SUB_BG_CLR',
            'PROINQ_ADMIN_EMAIL_CHANGE',
            'PROINQ_EMAIL_SUBJECT',
            'PROINQ_CUSTOMER_SUBJECT',
            'INQFORM_SEND_MAIL_ADMIN',
            'INQFORM_SEND_MAIL_CUSTOMER',
        ];
        $params = Configuration::getMultiple($params);
        extract($params);
        $params['PROINQ_ON_OFF'] = ((empty($PROINQ_ON_OFF)) ? 'yes' : $PROINQ_ON_OFF);
        $params['PROINQ_PRICE_EMPTY'] = ((empty($PROINQ_PRICE_EMPTY)) ? 'yes' : $PROINQ_PRICE_EMPTY);
        $params['PROINQ_HIDE_ATC_BTN'] = ((empty($PROINQ_HIDE_ATC_BTN)) ? 'no' : $PROINQ_HIDE_ATC_BTN);
        $params['PROINQ_STOCK_EMPTY'] = ((empty($PROINQ_STOCK_EMPTY)) ? 'yes' : $PROINQ_STOCK_EMPTY);
        $params['PROINQ_HIDE_ATC_STOCK_EMPTY'] = ((empty($PROINQ_HIDE_ATC_STOCK_EMPTY)) ? 'no' : $PROINQ_HIDE_ATC_STOCK_EMPTY);
        $params['PRODUCTINQUIRY_FORM_LOCATION'] = ((empty($PRODUCTINQUIRY_FORM_LOCATION)) ? '1' : $PRODUCTINQUIRY_FORM_LOCATION);
        $params['INQFORM_NAME_LABEL'] = ((empty($INQFORM_NAME_LABEL)) ? 'Customer Name' : $INQFORM_NAME_LABEL);
        $params['CUS_NAME_ERROR_MSG'] = ((empty($CUS_NAME_ERROR_MSG)) ? 'error customer name' : $CUS_NAME_ERROR_MSG);
        $params['INQFORM_CUSNAME_REQUIRE'] = ((empty($INQFORM_CUSNAME_REQUIRE)) ? 'yes' : $INQFORM_CUSNAME_REQUIRE);
        $params['INQFORM_EMAIL_LABEL'] = ((empty($INQFORM_EMAIL_LABEL)) ? 'Customer E-mail' : $INQFORM_EMAIL_LABEL);
        $params['INQFORM_EMAIL_REQUIRE_TEXT'] = ((empty($INQFORM_EMAIL_REQUIRE_TEXT)) ? 'customer e-mail error' : $INQFORM_EMAIL_REQUIRE_TEXT);
        $params['INQFORM_CUSEMAIL_REQ'] = ((empty($INQFORM_CUSEMAIL_REQ)) ? 'yes' : $INQFORM_CUSEMAIL_REQ);
        $params['INQFORM_CUSNUMBER_LABEL'] = ((empty($INQFORM_CUSNUMBER_LABEL)) ? 'Phone Number' : $INQFORM_CUSNUMBER_LABEL);
        $params['INQFORM_CUSNUMBER_REQ_TEXT'] = ((empty($INQFORM_CUSNUMBER_REQ_TEXT)) ? 'Phone Number error' : $INQFORM_CUSNUMBER_REQ_TEXT);
        $params['INQFORM_CUSMAIL_REQ_ENABLE'] = ((empty($INQFORM_CUSMAIL_REQ_ENABLE)) ? 'yes' : $INQFORM_CUSMAIL_REQ_ENABLE);
        $params['INQFORM_INQMSG_LABEL'] = ((empty($INQFORM_INQMSG_LABEL)) ? 'Inquiry' : $INQFORM_INQMSG_LABEL);
        $params['INQFORM_INQMSG_ERRORTEXT'] = ((empty($INQFORM_INQMSG_ERRORTEXT)) ? 'Inquiry error' : $INQFORM_INQMSG_ERRORTEXT);
        $params['INQFORM_MSG_REQ_ENABLE'] = ((empty($INQFORM_MSG_REQ_ENABLE)) ? 'yes' : $INQFORM_MSG_REQ_ENABLE);
        $params['INQFORM_POPUP_TITLE'] = ((empty($INQFORM_POPUP_TITLE)) ? 'Product Inquiri' : $INQFORM_POPUP_TITLE);
        $params['INQFORM_PRO_TAB_TITLE'] = ((empty($INQFORM_PRO_TAB_TITLE)) ? 'Product Inquiri' : $INQFORM_PRO_TAB_TITLE);
        $params['INQFORM_FORM_BTN_TITLE'] = ((empty($INQFORM_FORM_BTN_TITLE)) ? 'Product Inquiri' : $INQFORM_FORM_BTN_TITLE);
        $params['INQFORM_SUBBTN_TEXT'] = ((empty($INQFORM_SUBBTN_TEXT)) ? 'Submit' : $INQFORM_SUBBTN_TEXT);
        $params['INQFORM_SUCCESS_MSG'] = ((empty($INQFORM_SUCCESS_MSG)) ? 'Your inquiry send successfully.' : $INQFORM_SUCCESS_MSG);
        $params['PROINQ_POPUP_BG_COLOR'] = ((empty($PROINQ_POPUP_BG_COLOR)) ? '#ffffff' : $PROINQ_POPUP_BG_COLOR);
        $params['PROINQ_POPUP_HEADING_CLR'] = ((empty($PROINQ_POPUP_HEADING_CLR)) ? '#000000' : $PROINQ_POPUP_HEADING_CLR);
        $params['PROINQ_POPUP_LABEL_CLR'] = ((empty($PROINQ_POPUP_LABEL_CLR)) ? '#000000' : $PROINQ_POPUP_LABEL_CLR);
        $params['PROINQ_BUTTON_CLR'] = ((empty($PROINQ_BUTTON_CLR)) ? '#24b9d7' : $PROINQ_BUTTON_CLR);
        $params['PROINQ_BUTTON_TEXT_CLR'] = ((empty($PROINQ_BUTTON_TEXT_CLR)) ? '#ffffff' : $PROINQ_BUTTON_TEXT_CLR);
        $params['PROINQ_BUTTON_SUB_TEXT_CLR'] = ((empty($PROINQ_BUTTON_SUB_TEXT_CLR)) ? '#ffffff' : $PROINQ_BUTTON_SUB_TEXT_CLR);
        $params['PROINQ_BUTTON_SUB_BG_CLR'] = ((empty($PROINQ_BUTTON_SUB_BG_CLR)) ? '#24b9d7' : $PROINQ_BUTTON_SUB_BG_CLR);
        $admin_email = Configuration::get('PS_SHOP_EMAIL');
        $params['PROINQ_ADMIN_EMAIL_CHANGE'] = ((empty($PROINQ_ADMIN_EMAIL_CHANGE)) ?  $admin_email : $PROINQ_ADMIN_EMAIL_CHANGE);
        $params['PROINQ_EMAIL_SUBJECT'] = ((empty($PROINQ_EMAIL_SUBJECT)) ? 'Inquiry about product'  : $PROINQ_EMAIL_SUBJECT);
        $params['PROINQ_CUSTOMER_SUBJECT'] = ((empty($PROINQ_CUSTOMER_SUBJECT)) ? 'Inquiry about product'  : $PROINQ_CUSTOMER_SUBJECT);
        $params['INQFORM_SEND_MAIL_ADMIN'] = ((empty($INQFORM_SEND_MAIL_ADMIN)) ? 'yes'  : $INQFORM_SEND_MAIL_ADMIN);
        $params['INQFORM_SEND_MAIL_CUSTOMER'] = ((empty($INQFORM_SEND_MAIL_CUSTOMER)) ? 'yes'  : $INQFORM_SEND_MAIL_CUSTOMER);

        return $params;
    }

    public function getContent()
    {
        $output = '';
        if (Tools::isSubmit('ProInqsendTokenMessage')) {
            Configuration::updateValue('PROINQ_ON_OFF', Tools::getValue('PROINQ_ON_OFF'));
            Configuration::updateValue('PROINQ_PRICE_EMPTY', Tools::getValue('PROINQ_PRICE_EMPTY'));
            Configuration::updateValue('PROINQ_HIDE_ATC_BTN', Tools::getValue('PROINQ_HIDE_ATC_BTN'));
            Configuration::updateValue('PROINQ_STOCK_EMPTY', Tools::getValue('PROINQ_STOCK_EMPTY'));
            Configuration::updateValue('PROINQ_HIDE_ATC_STOCK_EMPTY', Tools::getValue('PROINQ_HIDE_ATC_STOCK_EMPTY'));
            Configuration::updateValue('PRODUCTINQUIRY_FORM_LOCATION', Tools::getValue('PRODUCTINQUIRY_FORM_LOCATION'));
            Configuration::updateValue('INQFORM_NAME_LABEL', Tools::getValue('INQFORM_NAME_LABEL'));
            Configuration::updateValue('CUS_NAME_ERROR_MSG', Tools::getValue('CUS_NAME_ERROR_MSG'));
            Configuration::updateValue('INQFORM_CUSNAME_REQUIRE', Tools::getValue('INQFORM_CUSNAME_REQUIRE'));
            Configuration::updateValue('INQFORM_EMAIL_LABEL', Tools::getValue('INQFORM_EMAIL_LABEL'));
            Configuration::updateValue('INQFORM_EMAIL_REQUIRE_TEXT', Tools::getValue('INQFORM_EMAIL_REQUIRE_TEXT'));
            Configuration::updateValue('INQFORM_CUSNUMBER_LABEL', Tools::getValue('INQFORM_CUSNUMBER_LABEL'));
            Configuration::updateValue('INQFORM_CUSNUMBER_REQ_TEXT', Tools::getValue('INQFORM_CUSNUMBER_REQ_TEXT'));
            Configuration::updateValue('INQFORM_CUSMAIL_REQ_ENABLE', Tools::getValue('INQFORM_CUSMAIL_REQ_ENABLE'));
            Configuration::updateValue('INQFORM_INQMSG_LABEL', Tools::getValue('INQFORM_INQMSG_LABEL'));
            Configuration::updateValue('INQFORM_INQMSG_ERRORTEXT', Tools::getValue('INQFORM_INQMSG_ERRORTEXT'));
            Configuration::updateValue('INQFORM_CUSEMAIL_REQ', Tools::getValue('INQFORM_CUSEMAIL_REQ'));
            Configuration::updateValue('INQFORM_MSG_REQ_ENABLE', Tools::getValue('INQFORM_MSG_REQ_ENABLE'));
            Configuration::updateValue('INQFORM_POPUP_TITLE', Tools::getValue('INQFORM_POPUP_TITLE'));
            Configuration::updateValue('INQFORM_PRO_TAB_TITLE', Tools::getValue('INQFORM_PRO_TAB_TITLE'));
            Configuration::updateValue('INQFORM_FORM_BTN_TITLE', Tools::getValue('INQFORM_FORM_BTN_TITLE'));
            Configuration::updateValue('INQFORM_SUBBTN_TEXT', Tools::getValue('INQFORM_SUBBTN_TEXT'));
            Configuration::updateValue('INQFORM_SUCCESS_MSG', Tools::getValue('INQFORM_SUCCESS_MSG'));
            Configuration::updateValue('PROINQ_POPUP_BG_COLOR', Tools::getValue('PROINQ_POPUP_BG_COLOR'));
            Configuration::updateValue('PROINQ_POPUP_HEADING_CLR', Tools::getValue('PROINQ_POPUP_HEADING_CLR'));
            Configuration::updateValue('PROINQ_POPUP_LABEL_CLR', Tools::getValue('PROINQ_POPUP_LABEL_CLR'));
            Configuration::updateValue('PROINQ_BUTTON_CLR', Tools::getValue('PROINQ_BUTTON_CLR'));
            Configuration::updateValue('PROINQ_BUTTON_TEXT_CLR', Tools::getValue('PROINQ_BUTTON_TEXT_CLR'));
            Configuration::updateValue('PROINQ_BUTTON_SUB_TEXT_CLR', Tools::getValue('PROINQ_BUTTON_SUB_TEXT_CLR'));
            Configuration::updateValue('PROINQ_BUTTON_SUB_BG_CLR', Tools::getValue('PROINQ_BUTTON_SUB_BG_CLR'));
            Configuration::updateValue('PROINQ_ADMIN_EMAIL_CHANGE', Tools::getValue('PROINQ_ADMIN_EMAIL_CHANGE'));
            Configuration::updateValue('PROINQ_EMAIL_SUBJECT', Tools::getValue('PROINQ_EMAIL_SUBJECT'));
            Configuration::updateValue('PROINQ_CUSTOMER_SUBJECT', Tools::getValue('PROINQ_CUSTOMER_SUBJECT'));
            Configuration::updateValue('INQFORM_SEND_MAIL_ADMIN', Tools::getValue('INQFORM_SEND_MAIL_ADMIN'));
            Configuration::updateValue('INQFORM_SEND_MAIL_CUSTOMER', Tools::getValue('INQFORM_SEND_MAIL_CUSTOMER'));
            $output .= $this->displayConfirmation($this->trans(
                    'Settings updated.',
                    [],
                    'Admin.Global',
                ));
        }
        if (isset($this->ps_version)) {
            $params = $this->getParams();
            $moduleAdminLink = Context::getContext()->link->getAdminLink('AdminModules', true, false, $params);
        } else {
            $comurl = '&configure=' . $this->name . '&module_name=' . $this->name;
            $moduleAdminLink = Context::getContext()->link->getAdminLink('AdminModules', true) . $comurl;
        }
        $currentPage = 'ocproductinquiry';
        $page = Tools::getValue('page');
        if (!empty($page)) {
            $currentPage = Tools::getValue('page');
        }
        $params = $this->getParams();
        $this->context->smarty->assign([
            'module_name' => $this->name,
            'module_version' => $this->version,
            'moduleAdminLink' => $moduleAdminLink,
            'module_display' => $this->displayName,
            'currentPage' => $currentPage,
            'ps_base_dir' => Tools::getHttpHost(true),
            'ps_version' => _PS_VERSION_,
            'isPs17' => isset($this->ps_version),
            'productinquiri_params' => $params,
        ]);
        $output .= '';

        return $output . $this->context->smarty->fetch($this->local_path . 'views/templates/admin/product_inquiry_admin.tpl');
    }
}